
.. _gallery:

Circuit Gallery
===============

Because many examples in the gallery make use of the walrus operator (`:=`), Python 3.8+ is required to run these without modification.


.. toctree::

   analog
   opamp
   logicgate
   timing
   solidstate
   ic
   signalproc
   flowcharting
   styles